@@ -6,7 +6,7 @@ from queue import Queue
 from threading import Thread
 import os
 from .coco_convert import get_jsons_dict
-# from .pixel_convert import convert
+from .pixel_convert import convert
 from io import BytesIO
 
 class AppWorkerUpload(Thread):
